==> speech-analytic-testing_6.1.0_database.tar.gz: database/init_data/dbo.TemplateTheme.Table.sql <==
INSERT [dbo].[TemplateTheme] ([VCC], [TemplateId], [ID], [Order], [Description], [Category1], [Category2], [CreatedDate], [CreatedByUserId], [LastModifiedDate], [LastModifiedByUserId], [TimeStamp]) VALUES (N'system', N'es_banca_template', N'0D632FC9-954C-4149-8048-CF7E1C345A7D', 1, N'Oportunidad', N'Volver a llamar', N'Fin de mes', GETUTCDATE(), N'analytic', GETUTCDATE(), N'analytic', GETUTCDATE())
INSERT [dbo].[TemplateTheme] ([VCC], [TemplateId], [ID], [Order], [Description], [Category1], [Category2], [CreatedDate], [CreatedByUserId], [LastModifiedDate], [LastModifiedByUserId], [TimeStamp]) VALUES (N'system', N'es_banca_template', N'0D9C183B-289F-47B8-AF96-714371A6D2D9', 1, N'Tres Líneas', N'Línea', NULL, GETUTCDATE(), N'analytic', GETUTCDATE(), N'analytic', GETUTCDATE())
INSERT [dbo].[TemplateTheme] ([VCC], [TemplateId], [ID], [Order], [Description], [Category1], [Category2], [CreatedDate], [CreatedByUserId], [LastModifiedDate], [LastModifiedByUserId], [TimeStamp]) VALUES (N'system', N'es_banca_template', N'339FC805-795D-4414-AC72-E7E57A77BEF7', 1, N'Huawei', N'Línea', N'Quiere equipo', GETUTCDATE(), N'analytic', GETUTCDATE(), N'analytic', GETUTCDATE())
INSERT [dbo].[TemplateTheme] ([VCC], [TemplateId], [ID], [Order], [Description], [Category1], [Category2], [CreatedDate], [CreatedByUserId], [LastModifiedDate], [LastModifiedByUserId], [TimeStamp]) VALUES (N'system', N'es_banca_template', N'3C72C38A-56E8-4583-B01A-DB771DA3ACA7', 3, N'Otros', N'Volver a llamar', N'Fin de mes', GETUTCDATE(), N'analytic', GETUTCDATE(), N'analytic', GETUTCDATE())
INSERT [dbo].[TemplateTheme] ([VCC], [TemplateId], [ID], [Order], [Description], [Category1], [Category2], [CreatedDate], [CreatedByUserId], [LastModifiedDate], [LastModifiedByUserId], [TimeStamp]) VALUES (N'system', N'es_banca_template', N'4B1C7661-3A9A-4F15-A8EC-C27A4B2F9E50', 2, N'febrero', N'Volver a llamar', NULL, GETUTCDATE(), N'analytic', GETUTCDATE(), N'analytic', GETUTCDATE())
INSERT [dbo].[TemplateTheme] ([VCC], [TemplateId], [ID], [Order], [Description], [Category1], [Category2], [CreatedDate], [CreatedByUserId], [LastModifiedDate], [LastModifiedByUserId], [TimeStamp]) VALUES (N'system', N'es_banca_template', N'932C946D-46C1-4794-A142-9CB409F28213', 4, N'No llamar', NULL, NULL, GETUTCDATE(), N'analytic', GETUTCDATE(), N'analytic', GETUTCDATE())
INSERT [dbo].[TemplateTheme] ([VCC], [TemplateId], [ID], [Order], [Description], [Category1], [Category2], [CreatedDate], [CreatedByUserId], [LastModifiedDate], [LastModifiedByUserId], [TimeStamp]) VALUES (N'system', N'es_banca_template', N'CB77E731-A7E1-432C-85F6-7AD1DA70F433', 1, N'Desea mantenerse', N'Está con otro operador', NULL, GETUTCDATE(), N'analytic', GETUTCDATE(), N'analytic', GETUTCDATE())
INSERT [dbo].[TemplateTheme] ([VCC], [TemplateId], [ID], [Order], [Description], [Category1], [Category2], [CreatedDate], [CreatedByUserId], [LastModifiedDate], [LastModifiedByUserId], [TimeStamp]) VALUES (N'system', N'es_banca_template', N'CD80075D-74A0-4FD5-8152-9DEAADA35D7E', 2, N'En Este Momento', N'Volver a llamar', N'Fin de mes', GETUTCDATE(), N'analytic', GETUTCDATE(), N'analytic', GETUTCDATE())
INSERT [dbo].[TemplateTheme] ([VCC], [TemplateId], [ID], [Order], [Description], [Category1], [Category2], [CreatedDate], [CreatedByUserId], [LastModifiedDate], [LastModifiedByUserId], [TimeStamp]) VALUES (N'system', N'es_banca_template', N'DDA9810B-BFAB-429D-BB91-4415ED6A143F', 1, N'Nokia', N'Línea', N'Compra', GETUTCDATE(), N'analytic', GETUTCDATE(), N'analytic', GETUTCDATE())
INSERT [dbo].[TemplateTheme] ([VCC], [TemplateId], [ID], [Order], [Description], [Category1], [Category2], [CreatedDate], [CreatedByUserId], [LastModifiedDate], [LastModifiedByUserId], [TimeStamp]) VALUES (N'system', N'es_banca_template', N'F41FC349-830D-48AC-B55B-7A1401E7AC77', 4, N'ultimo', N'Línea', NULL, GETUTCDATE(), N'analytic', GETUTCDATE(), N'analytic', GETUTCDATE()
GO
INSERT [dbo].[TemplateTheme] ([VCC], [TemplateId], [ID], [Order], [Description], [Category1], [Category2], [CreatedDate], [CreatedByUserId], [LastModifiedDate], [LastModifiedByUserId], [TimeStamp]) VALUES (N'system', N'en_banca_template', NEWID(), 1, N'Chance', N'Calling again', N'End of the month', GETUTCDATE(), N'analytic', GETUTCDATE(), N'analytic', GETUTCDATE())
INSERT [dbo].[TemplateTheme] ([VCC], [TemplateId], [ID], [Order], [Description], [Category1], [Category2], [CreatedDate], [CreatedByUserId], [LastModifiedDate], [LastModifiedByUserId], [TimeStamp]) VALUES (N'system', N'en_banca_template', NEWID(), 1, N'Three lines', N'Line', NULL, GETUTCDATE(), N'analytic', GETUTCDATE(), N'analytic', GETUTCDATE())
INSERT [dbo].[TemplateTheme] ([VCC], [TemplateId], [ID], [Order], [Description], [Category1], [Category2], [CreatedDate], [CreatedByUserId], [LastModifiedDate], [LastModifiedByUserId], [TimeStamp]) VALUES (N'system', N'en_banca_template', NEWID(), 1, N'Huawei', N'Line', N'Want team', GETUTCDATE(), N'analytic', GETUTCDATE(), N'analytic', GETUTCDATE())
INSERT [dbo].[TemplateTheme] ([VCC], [TemplateId], [ID], [Order], [Description], [Category1], [Category2], [CreatedDate], [CreatedByUserId], [LastModifiedDate], [LastModifiedByUserId], [TimeStamp]) VALUES (N'system', N'en_banca_template', NEWID(), 3, N'Others', N'Calling again', N'End of the month', GETUTCDATE(), N'analytic', GETUTCDATE(), N'analytic', GETUTCDATE())
INSERT [dbo].[TemplateTheme] ([VCC], [TemplateId], [ID], [Order], [Description], [Category1], [Category2], [CreatedDate], [CreatedByUserId], [LastModifiedDate], [LastModifiedByUserId], [TimeStamp]) VALUES (N'system', N'en_banca_template', NEWID(), 2, N'February', N'Calling again', NULL, GETUTCDATE(), N'analytic', GETUTCDATE(), N'analytic', GETUTCDATE())
INSERT [dbo].[TemplateTheme] ([VCC], [TemplateId], [ID], [Order], [Description], [Category1], [Category2], [CreatedDate], [CreatedByUserId], [LastModifiedDate], [LastModifiedByUserId], [TimeStamp]) VALUES (N'system', N'en_banca_template', NEWID(), 4, N'Do not call', NULL, NULL, GETUTCDATE(), N'analytic', GETUTCDATE(), N'analytic', GETUTCDATE())
INSERT [dbo].[TemplateTheme] ([VCC], [TemplateId], [ID], [Order], [Description], [Category1], [Category2], [CreatedDate], [CreatedByUserId], [LastModifiedDate], [LastModifiedByUserId], [TimeStamp]) VALUES (N'system', N'en_banca_template', N'60B6651D-1619-41CD-9FAD-BEF7E7D502D7', 1, N'Want to stay', N'You are with another operator', NULL, GETUTCDATE(), N'analytic', GETUTCDATE(), N'analytic', GETUTCDATE())
INSERT [dbo].[TemplateTheme] ([VCC], [TemplateId], [ID], [Order], [Description], [Category1], [Category2], [CreatedDate], [CreatedByUserId], [LastModifiedDate], [LastModifiedByUserId], [TimeStamp]) VALUES (N'system', N'en_banca_template', NEWID(), 2, N'At this time', N'Calling again', N'End of the month', GETUTCDATE(), N'analytic', GETUTCDATE(), N'analytic', GETUTCDATE())
INSERT [dbo].[TemplateTheme] ([VCC], [TemplateId], [ID], [Order], [Description], [Category1], [Category2], [CreatedDate], [CreatedByUserId], [LastModifiedDate], [LastModifiedByUserId], [TimeStamp]) VALUES (N'system', N'en_banca_template', NEWID(), 1, N'Nokia', N'Line', N'Buys', GETUTCDATE(), N'analytic', GETUTCDATE(), N'analytic', GETUTCDATE())
INSERT [dbo].[TemplateTheme] ([VCC], [TemplateId], [ID], [Order], [Description], [Category1], [Category2], [CreatedDate], [CreatedByUserId], [LastModifiedDate], [LastModifiedByUserId], [TimeStamp]) VALUES (N'system', N'en_banca_template', NEWID(), 4, N'Latest', N'Line', NULL, GETUTCDATE(), N'analytic', GETUTCDATE(), N'analytic', GETUTCDATE())
GO

==> speech-analytic-testing_7.4.4_database.tar.gz: database/init_data/dbo.TemplateTheme.Table.sql <==
INSERT [dbo].[TemplateTheme] ([VCC], [TemplateId], [ID], [Order], [Description], [Category1], [Category2], [CreatedDate], [CreatedByUserId], [LastModifiedDate], [LastModifiedByUserId], [TimeStamp]) VALUES (N'system', N'es_banca_template', N'0D632FC9-954C-4149-8048-CF7E1C345A7D', 1, N'Oportunidad', N'Volver a llamar', N'Fin de mes', GETUTCDATE(), N'analytic', GETUTCDATE(), N'analytic', GETUTCDATE())
INSERT [dbo].[TemplateTheme] ([VCC], [TemplateId], [ID], [Order], [Description], [Category1], [Category2], [CreatedDate], [CreatedByUserId], [LastModifiedDate], [LastModifiedByUserId], [TimeStamp]) VALUES (N'system', N'es_banca_template', N'0D9C183B-289F-47B8-AF96-714371A6D2D9', 1, N'Tres Líneas', N'Línea', NULL, GETUTCDATE(), N'analytic', GETUTCDATE(), N'analytic', GETUTCDATE())
INSERT [dbo].[TemplateTheme] ([VCC], [TemplateId], [ID], [Order], [Description], [Category1], [Category2], [CreatedDate], [CreatedByUserId], [LastModifiedDate], [LastModifiedByUserId], [TimeStamp]) VALUES (N'system', N'es_banca_template', N'339FC805-795D-4414-AC72-E7E57A77BEF7', 1, N'Huawei', N'Línea', N'Quiere equipo', GETUTCDATE(), N'analytic', GETUTCDATE(), N'analytic', GETUTCDATE())
INSERT [dbo].[TemplateTheme] ([VCC], [TemplateId], [ID], [Order], [Description], [Category1], [Category2], [CreatedDate], [CreatedByUserId], [LastModifiedDate], [LastModifiedByUserId], [TimeStamp]) VALUES (N'system', N'es_banca_template', N'3C72C38A-56E8-4583-B01A-DB771DA3ACA7', 3, N'Otros', N'Volver a llamar', N'Fin de mes', GETUTCDATE(), N'analytic', GETUTCDATE(), N'analytic', GETUTCDATE())
INSERT [dbo].[TemplateTheme] ([VCC], [TemplateId], [ID], [Order], [Description], [Category1], [Category2], [CreatedDate], [CreatedByUserId], [LastModifiedDate], [LastModifiedByUserId], [TimeStamp]) VALUES (N'system', N'es_banca_template', N'4B1C7661-3A9A-4F15-A8EC-C27A4B2F9E50', 2, N'febrero', N'Volver a llamar', NULL, GETUTCDATE(), N'analytic', GETUTCDATE(), N'analytic', GETUTCDATE())
INSERT [dbo].[TemplateTheme] ([VCC], [TemplateId], [ID], [Order], [Description], [Category1], [Category2], [CreatedDate], [CreatedByUserId], [LastModifiedDate], [LastModifiedByUserId], [TimeStamp]) VALUES (N'system', N'es_banca_template', N'932C946D-46C1-4794-A142-9CB409F28213', 4, N'No llamar', NULL, NULL, GETUTCDATE(), N'analytic', GETUTCDATE(), N'analytic', GETUTCDATE())
INSERT [dbo].[TemplateTheme] ([VCC], [TemplateId], [ID], [Order], [Description], [Category1], [Category2], [CreatedDate], [CreatedByUserId], [LastModifiedDate], [LastModifiedByUserId], [TimeStamp]) VALUES (N'system', N'es_banca_template', N'CB77E731-A7E1-432C-85F6-7AD1DA70F433', 1, N'Desea mantenerse', N'Está con otro operador', NULL, GETUTCDATE(), N'analytic', GETUTCDATE(), N'analytic', GETUTCDATE())
INSERT [dbo].[TemplateTheme] ([VCC], [TemplateId], [ID], [Order], [Description], [Category1], [Category2], [CreatedDate], [CreatedByUserId], [LastModifiedDate], [LastModifiedByUserId], [TimeStamp]) VALUES (N'system', N'es_banca_template', N'CD80075D-74A0-4FD5-8152-9DEAADA35D7E', 2, N'En Este Momento', N'Volver a llamar', N'Fin de mes', GETUTCDATE(), N'analytic', GETUTCDATE(), N'analytic', GETUTCDATE())
INSERT [dbo].[TemplateTheme] ([VCC], [TemplateId], [ID], [Order], [Description], [Category1], [Category2], [CreatedDate], [CreatedByUserId], [LastModifiedDate], [LastModifiedByUserId], [TimeStamp]) VALUES (N'system', N'es_banca_template', N'DDA9810B-BFAB-429D-BB91-4415ED6A143F', 1, N'Nokia', N'Línea', N'Compra', GETUTCDATE(), N'analytic', GETUTCDATE(), N'analytic', GETUTCDATE())
INSERT [dbo].[TemplateTheme] ([VCC], [TemplateId], [ID], [Order], [Description], [Category1], [Category2], [CreatedDate], [CreatedByUserId], [LastModifiedDate], [LastModifiedByUserId], [TimeStamp]) VALUES (N'system', N'es_banca_template', N'F41FC349-830D-48AC-B55B-7A1401E7AC77', 4, N'ultimo', N'Línea', NULL, GETUTCDATE(), N'analytic', GETUTCDATE(), N'analytic', GETUTCDATE())
GO
INSERT [dbo].[TemplateTheme] ([VCC], [TemplateId], [ID], [Order], [Description], [Category1], [Category2], [CreatedDate], [CreatedByUserId], [LastModifiedDate], [LastModifiedByUserId], [TimeStamp]) VALUES (N'system', N'en_banca_template', NEWID(), 1, N'Chance', N'Calling again', N'End of the month', GETUTCDATE(), N'analytic', GETUTCDATE(), N'analytic', GETUTCDATE())
INSERT [dbo].[TemplateTheme] ([VCC], [TemplateId], [ID], [Order], [Description], [Category1], [Category2], [CreatedDate], [CreatedByUserId], [LastModifiedDate], [LastModifiedByUserId], [TimeStamp]) VALUES (N'system', N'en_banca_template', NEWID(), 1, N'Three lines', N'Line', NULL, GETUTCDATE(), N'analytic', GETUTCDATE(), N'analytic', GETUTCDATE())
INSERT [dbo].[TemplateTheme] ([VCC], [TemplateId], [ID], [Order], [Description], [Category1], [Category2], [CreatedDate], [CreatedByUserId], [LastModifiedDate], [LastModifiedByUserId], [TimeStamp]) VALUES (N'system', N'en_banca_template', NEWID(), 1, N'Huawei', N'Line', N'Want team', GETUTCDATE(), N'analytic', GETUTCDATE(), N'analytic', GETUTCDATE())
INSERT [dbo].[TemplateTheme] ([VCC], [TemplateId], [ID], [Order], [Description], [Category1], [Category2], [CreatedDate], [CreatedByUserId], [LastModifiedDate], [LastModifiedByUserId], [TimeStamp]) VALUES (N'system', N'en_banca_template', NEWID(), 3, N'Others', N'Calling again', N'End of the month', GETUTCDATE(), N'analytic', GETUTCDATE(), N'analytic', GETUTCDATE())
INSERT [dbo].[TemplateTheme] ([VCC], [TemplateId], [ID], [Order], [Description], [Category1], [Category2], [CreatedDate], [CreatedByUserId], [LastModifiedDate], [LastModifiedByUserId], [TimeStamp]) VALUES (N'system', N'en_banca_template', NEWID(), 2, N'February', N'Calling again', NULL, GETUTCDATE(), N'analytic', GETUTCDATE(), N'analytic', GETUTCDATE())
INSERT [dbo].[TemplateTheme] ([VCC], [TemplateId], [ID], [Order], [Description], [Category1], [Category2], [CreatedDate], [CreatedByUserId], [LastModifiedDate], [LastModifiedByUserId], [TimeStamp]) VALUES (N'system', N'en_banca_template', NEWID(), 4, N'Do not call', NULL, NULL, GETUTCDATE(), N'analytic', GETUTCDATE(), N'analytic', GETUTCDATE())
INSERT [dbo].[TemplateTheme] ([VCC], [TemplateId], [ID], [Order], [Description], [Category1], [Category2], [CreatedDate], [CreatedByUserId], [LastModifiedDate], [LastModifiedByUserId], [TimeStamp]) VALUES (N'system', N'en_banca_template', N'60B6651D-1619-41CD-9FAD-BEF7E7D502D7', 1, N'Want to stay', N'You are with another operator', NULL, GETUTCDATE(), N'analytic', GETUTCDATE(), N'analytic', GETUTCDATE())
INSERT [dbo].[TemplateTheme] ([VCC], [TemplateId], [ID], [Order], [Description], [Category1], [Category2], [CreatedDate], [CreatedByUserId], [LastModifiedDate], [LastModifiedByUserId], [TimeStamp]) VALUES (N'system', N'en_banca_template', NEWID(), 2, N'At this time', N'Calling again', N'End of the month', GETUTCDATE(), N'analytic', GETUTCDATE(), N'analytic', GETUTCDATE())
INSERT [dbo].[TemplateTheme] ([VCC], [TemplateId], [ID], [Order], [Description], [Category1], [Category2], [CreatedDate], [CreatedByUserId], [LastModifiedDate], [LastModifiedByUserId], [TimeStamp]) VALUES (N'system', N'en_banca_template', NEWID(), 1, N'Nokia', N'Line', N'Buys', GETUTCDATE(), N'analytic', GETUTCDATE(), N'analytic', GETUTCDATE())
INSERT [dbo].[TemplateTheme] ([VCC], [TemplateId], [ID], [Order], [Description], [Category1], [Category2], [CreatedDate], [CreatedByUserId], [LastModifiedDate], [LastModifiedByUserId], [TimeStamp]) VALUES (N'system', N'en_banca_template', NEWID(), 4, N'Latest', N'Line', NULL, GETUTCDATE(), N'analytic', GETUTCDATE(), N'analytic', GETUTCDATE())
GO
